import tkinter as tk
import time
import queue

import gui.Popup as Popup
import gui.graph as Graph

class MainWindow(tk.Frame):
  def __init__(self, root, up_queue, down_queue,calibration_state):
    self.root = root
    self.popup = None
    self.calibration_state = calibration_state
    self.down_queue = down_queue
    self.up_queue = up_queue
    tk.Frame.__init__(self, root)

    self.graph = Graph.Graph(self)
    self.graph.pack(fill=tk.BOTH, side=tk.LEFT, expand=True)

    self.controls = tk.Frame(self)
    self.controls.pack(fill=tk.BOTH, side=tk.RIGHT)

    l = tk.Label(self.controls, text="your widgets go here...", anchor="c")
    l.pack(side="top", fill="both", expand=True)
    calibrate_button = tk.Button(self.controls,text="calibrate",command=self.calibrate)
    calibrate_button.pack(side="top")

  def update(self):
    ac_data = []
    while self.up_queue.qsize() > 0:
      name, data = self.up_queue.get()
      if name == "ac_data":
        ac_data.append(data)
    if len(ac_data) > 0:
      self.graph.update([ac_data])

    if self.popup:
      self.popup.update()
    self.root.after(30, self.update)

  def calibrate(self):
    self.down_queue.put("calibrate")
    pu_root = tk.Tk()
    pu_root.title("Calibration")
    self.popup = Popup.CalibrationPopUp(pu_root,self.up_queue,self.down_queue,self.calibration_state)
    self.popup.pack(side="top", fill="both", expand=True)
    
    
if __name__ == "__main__":
  root = tk.Tk()
  up_queue = queue.Queue()
  down_queue = queue.Queue()
  root.title("Tracking System")
  view = MainWindow(root,up_queue,down_queue,list())
  view.pack(side="top", fill="both", expand=True)
  view.update()
  root.mainloop()
